ezhc
====

**ezvis3d** stands for easy vis.js/Graph3d. `vis.js Graph3d`_ is a
popular, flexible, versatile, user friendly 3d visualisation javascript
library.

**ezvis3d** is a wrapper that lets you transparently access the full
configuration options of the library as described in their APIs,
directly from the `Jupyter notebook`_.

You just need to store the data in a `pandas`_ dataframe. See the
examples in these notebooks: + the `demo notebook`_. + a `Black and
Scholes formula viewer`_.

To install run from command line:

::

    pip install ezvis3d

.. _vis.js Graph3d: http://visjs.org/graph3d_examples.html
.. _Jupyter notebook: http://jupyter.org/
.. _pandas: http://pandas.pydata.org/
.. _demo notebook: http://nbviewer.ipython.org/github/oscar6echo/ezvis3d/blob/master/demo_ezvisd3.ipynb
.. _Black and Scholes formula viewer: http://nbviewer.ipython.org/github/oscar6echo/ezvis3d/blob/master/BlackScholesViewer.ipynb
